
/**
 ** Generated data (by mktypes.pl --array)
 **/
  { &bse_type_builtin_id_BseObject, bse_type_builtin_register_BseObject },
  { &bse_type_builtin_id_BseItem, bse_type_builtin_register_BseItem },
  { &bse_type_builtin_id_BsePcmWriter, bse_type_builtin_register_BsePcmWriter },
  { &bse_type_builtin_id_BseSource, bse_type_builtin_register_BseSource },
  { &bse_type_builtin_id_BseSnooper, bse_type_builtin_register_BseSnooper },
  { &bse_type_builtin_id_BseConstant, bse_type_builtin_register_BseConstant },
  { &bse_type_builtin_id_BseContainer, bse_type_builtin_register_BseContainer },
  { &bse_type_builtin_id_BseSuper, bse_type_builtin_register_BseSuper },
  { &bse_type_builtin_id_BseWaveRepo, bse_type_builtin_register_BseWaveRepo },
  { &bse_type_builtin_id_BseWaveOsc, bse_type_builtin_register_BseWaveOsc },
  { &bse_type_builtin_id_BseSNet, bse_type_builtin_register_BseSNet },
  { &bse_type_builtin_id_BseMidiSynth, bse_type_builtin_register_BseMidiSynth },
  { &bse_type_builtin_id_BseMidiIController, bse_type_builtin_register_BseMidiIController },
  { &bse_type_builtin_id_BseMidiVoiceInput, bse_type_builtin_register_BseMidiVoiceInput },
  { &bse_type_builtin_id_BseLadspaPlugin, bse_type_builtin_register_BseLadspaPlugin },
  { &bse_type_builtin_id_BseContextMerger, bse_type_builtin_register_BseContextMerger },
  { &bse_type_builtin_id_BseSubIPort, bse_type_builtin_register_BseSubIPort },
  { &bse_type_builtin_id_BsePlugin, bse_type_builtin_register_BsePlugin },
  { &bse_type_builtin_id_BseCSynth, bse_type_builtin_register_BseCSynth },
  { &bse_type_builtin_id_BseMidiDevice, bse_type_builtin_register_BseMidiDevice },
  { &bse_type_builtin_id_BseMidiDeviceNULL, bse_type_builtin_register_BseMidiDeviceNULL },
  { &bse_type_builtin_id_BseSong, bse_type_builtin_register_BseSong },
  { &bse_type_builtin_id_BseBiquadFilter, bse_type_builtin_register_BseBiquadFilter },
  { &bse_type_builtin_id_BseMidiNotifier, bse_type_builtin_register_BseMidiNotifier },
  { &bse_type_builtin_id_BseProject, bse_type_builtin_register_BseProject },
  { &bse_type_builtin_id_BseTrack, bse_type_builtin_register_BseTrack },
  { &bse_type_builtin_id_BseStorage, bse_type_builtin_register_BseStorage },
  { &bse_type_builtin_id_BsePart, bse_type_builtin_register_BsePart },
  { &bse_type_builtin_id_BseSubSynth, bse_type_builtin_register_BseSubSynth },
  { &bse_type_builtin_id_BseStandardOsc, bse_type_builtin_register_BseStandardOsc },
  { &bse_type_builtin_id_BseDataPocket, bse_type_builtin_register_BseDataPocket },
  { &bse_type_builtin_id_BseJanitor, bse_type_builtin_register_BseJanitor },
  { &bse_type_builtin_id_BseMidiDeviceOSS, bse_type_builtin_register_BseMidiDeviceOSS },
  { &bse_type_builtin_id_BsePcmOutput, bse_type_builtin_register_BsePcmOutput },
  { &bse_type_builtin_id_BsePcmInput, bse_type_builtin_register_BsePcmInput },
  { &bse_type_builtin_id_BseSubOPort, bse_type_builtin_register_BseSubOPort },
  { &bse_type_builtin_id_BseWave, bse_type_builtin_register_BseWave },
  { &bse_type_builtin_id_BseEditableSample, bse_type_builtin_register_BseEditableSample },
  { &bse_type_builtin_id_BseServer, bse_type_builtin_register_BseServer },
  { &bse_type_builtin_id_BseMidiVoiceSwitch, bse_type_builtin_register_BseMidiVoiceSwitch },
  { &bse_type_builtin_id_BseSubKeyboard, bse_type_builtin_register_BseSubKeyboard },
  { &bse_type_builtin_id_BseSubInstrument, bse_type_builtin_register_BseSubInstrument },
  { &bse_type_builtin_id_BsePcmDevice, bse_type_builtin_register_BsePcmDevice },
  { &bse_type_builtin_id_BsePcmDeviceOSS, bse_type_builtin_register_BsePcmDeviceOSS },
  { &bse_type_builtin_id_BseLadspaModule, bse_type_builtin_register_BseLadspaModule },
  { &bse_type_builtin_id_BseAmplifier, bse_type_builtin_register_BseAmplifier },

/**
 ** Generated data ends here
 **/
